@@ -10,7 +10,6 @@ import importlib.util
 import awyes.deploy
 import awyes.clients
 
-
 USER_CLIENT_NAME = "user"
 
 
@@ -18,30 +17,31 @@ def main():
     parser = argparse.ArgumentParser(description='Create an awyes deployment')
 
     parser.add_argument(
-        '--preview', action=argparse.BooleanOptionalAction, default=False,
+        '-p', '--preview', action=argparse.BooleanOptionalAction, default=False,
         help="Whether or not to execute the plan")
     parser.add_argument(
-        '--verbose', action=argparse.BooleanOptionalAction, default=True,
+        '-v', '--verbose', action=argparse.BooleanOptionalAction, default=True,
         help="Enable logging")
     parser.add_argument(
-        '--include-deps', action=argparse.BooleanOptionalAction, default=False,
+        '-d', '--include-deps', action=argparse.BooleanOptionalAction, default=True,
         help="When specifying an action, whether to include dependent actions")
     parser.add_argument(
         '--include-docker', action=argparse.BooleanOptionalAction,
         default=True,
         help="Include a docker client")
 
-    parser.add_argument('--workflow', type=str, required=False, default="",
+    parser.add_argument('-w', '--workflow', type=str, required=False, default="",
                         help='The awyes workflow type')
     parser.add_argument('--config', type=str, required=False,
                         default="awyes.yml", help='Path to awyes config')
     parser.add_argument('--clients', type=str, required=False,
                         default="awyes.py",
                         help='Path to user specified awyes clients')
-    parser.add_argument('--raw', type=str, required=False, default="",
+    parser.add_argument('-r', '--raw', type=str, required=False, default="",
                         help='Raw config to use in place of path')
-    parser.add_argument('--action', type=str, required=False, default="",
-                        help="A specific action to run")
+    parser.add_argument('-a', '--action', type=str, required=False, default="",
+                        help="The action name to run")
+
     args = parser.parse_args()
 
     # Load the config
@@ -58,6 +58,7 @@ def main():
         "s3": boto3.client("s3"),
         "ec2": boto3.client("ec2"),
         "ecr": boto3.client("ecr"),
+        "eks": boto3.client("eks"),
         "sts": boto3.client("sts"),
         "rds": boto3.client("rds"),
         "events": boto3.client("events"),
@@ -66,8 +67,10 @@ def main():
         "organizations": boto3.client("organizations"),
     }
 
-    if args.include_docker:
+    try:
         clients.update({"docker": docker.client.from_env()})
+    except Exception:
+        print("WARNING: couldn't find docker client. Using defaults")
 
     try:
         user_client_path = pathlib.Path(args.clients).resolve()
